summaryrefslogtreecommitdiffstats
path: root/lib/kotext/KoParagLayout.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kotext/KoParagLayout.h')
-rw-r--r--lib/kotext/KoParagLayout.h54
1 files changed, 27 insertions, 27 deletions
diff --git a/lib/kotext/KoParagLayout.h b/lib/kotext/KoParagLayout.h
index e3098f59..a60d3934 100644
--- a/lib/kotext/KoParagLayout.h
+++ b/lib/kotext/KoParagLayout.h
@@ -17,11 +17,11 @@
* Boston, MA 02110-1301, USA.
*/
-#ifndef koparaglayout_h
-#define koparaglayout_h
+#ifndef koparagtqlayout_h
+#define koparagtqlayout_h
#include <KoRuler.h> // for KoTabulatorList
-#include <qdom.h>
+#include <tqdom.h>
#include "KoBorder.h"
#include <koffice_export.h>
class KoSavingContext;
@@ -29,7 +29,7 @@ class KoGenStyle;
class KoParagCounter;
class KoParagStyle;
class KoOasisContext;
-class QColor;
+class TQColor;
/**
* This class holds the paragraph-specific formatting information
@@ -40,7 +40,7 @@ class KOTEXT_EXPORT KoParagLayout
{
public:
KoParagLayout();
- KoParagLayout( const KoParagLayout &layout ) { operator=( layout ); }
+ KoParagLayout( const KoParagLayout &tqlayout ) { operator=( tqlayout ); }
~KoParagLayout();
@@ -89,14 +89,14 @@ public:
double lineSpacingValue() const { return lineSpacing;}
void setLineSpacingValue(double _value) { lineSpacing = _value;}
- static QString* shadowCssCompat; // used for compat with koffice-1.2 when loading
+ static TQString* shadowCssCompat; // used for compat with koffice-1.2 when loading
bool joinBorder:1;
bool unused:7; // for future use
char pageBreaking; // Page breaking flags
- char direction; // QChar::Direction
+ char direction; // TQChar::Direction
/// Alignment flag (AlignAuto/AlignLeft/AlignRight/AlignJustify)
- char alignment; // Qt::AlignmentFlags
+ char tqalignment; // TQt::AlignmentFlags
KoBorder leftBorder, rightBorder, topBorder, bottomBorder;
/// The background color of the paragraph
@@ -106,7 +106,7 @@ public:
* In theory anyway: the background colour isn't used in rendering text
* yet, but it's nice to preserve the value.
*/
- QColor backgroundColor;
+ TQColor backgroundColor;
/** can be 0 if no counter set */
KoParagCounter* counter;
@@ -122,48 +122,48 @@ public:
const KoTabulatorList& tabList() const { return m_tabList; }
//! Assignment operator for KoParagLayout
/** Copy a paragraph layout.
*
* If you're modifying this, you might also need to modify
* KoTextParag::setParagLayout
*/
void operator=( const KoParagLayout & );
- /** Return a set of flags showing the differences between this and 'layout' */
- int compare( const KoParagLayout & layout ) const;
+ /** Return a set of flags showing the differences between this and 'tqlayout' */
+ int compare( const KoParagLayout & tqlayout ) const;
- /** Save this parag layout to XML.
+ /** Save this parag tqlayout to XML.
* This format is used by KWord for paragraphs, and by KPresenter+KWord for styles.
*/
- void saveParagLayout( QDomElement & parentElem, int alignment ) const;
+ void saveParagLayout( TQDomElement & tqparentElem, int tqalignment ) const;
- /** Load this parag layout from XML.
+ /** Load this parag tqlayout from XML.
* This format is used by KWord for paragraphs, and by KPresenter+KWord for styles.
*/
- static void loadParagLayout( KoParagLayout& layout, const QDomElement& parentElem, int docVersion = 2 );
+ static void loadParagLayout( KoParagLayout& tqlayout, const TQDomElement& tqparentElem, int docVersion = 2 );
- /// Load this parag layout from Oasis XML
- static void loadOasisParagLayout( KoParagLayout& layout, KoOasisContext& context );
- /// Save this parag layout to Oasis XML
+ /// Load this parag tqlayout from Oasis XML
+ static void loadOasisParagLayout( KoParagLayout& tqlayout, KoOasisContext& context );
+ /// Save this parag tqlayout to Oasis XML
/// @param savingStyle true if this is saved as part of a user style,
/// false when saving a paragraph
/// @param gs the style where all the properties will be saved to
/// @param context the current context
void saveOasis( KoGenStyle& gs, KoSavingContext& context, bool savingStyle ) const;
- /// Convert an alignment string into an alignment flag (load)
- static Qt::AlignmentFlags loadOasisAlignment( const QCString& str );
- /// Convert an alignment flag into an alignment string (save)
- static QCString saveOasisAlignment( Qt::AlignmentFlags alignment );
+ /// Convert an tqalignment string into an tqalignment flag (load)
+ static TQt::AlignmentFlags loadOasisAlignment( const TQCString& str );
+ /// Convert an tqalignment flag into an tqalignment string (save)
+ static TQCString saveOasisAlignment( TQt::AlignmentFlags tqalignment );
private:
- static int getAttribute(const QDomElement &element, const char *attributeName, int defaultValue) {
- QString value = element.attribute( attributeName );
+ static int getAttribute(const TQDomElement &element, const char *attributeName, int defaultValue) {
+ TQString value = element.attribute( attributeName );
return value.isNull() ? defaultValue : value.toInt();
}
- static double getAttribute(const QDomElement &element, const char *attributeName, double defaultValue) {
- QString value = element.attribute( attributeName );
+ static double getAttribute(const TQDomElement &element, const char *attributeName, double defaultValue) {
+ TQString value = element.attribute( attributeName );
return value.isNull() ? defaultValue : value.toDouble();
}
@@ -122,48 +122,48 @@ public:
const KoTabulatorList& tabList() const { return m_tabList; }
//! Assignment operator for KoParagLayout
- /** Copy a paragraph layout.
+ /** Copy a paragraph tqlayout.
*
* If you're modifying this, you might also need to modify